@@ -11,7 +11,8 @@ register = template.Library()
 def analytics(context):
     content = ""
     for kind, codes in getattr(settings, "METRON_SETTINGS", {}).items():
-        code = codes.get(int(settings.SITE_ID))
+        site_id = getattr(context.get("request"), "metron_site_id", settings.SITE_ID)
+        code = codes.get(int(site_id))
         if code is not None and "user" in context and "request" in context:
             t = template.loader.get_template("metron/_%s.html" % kind)
             content += t.render(template.Context({
